summaryrefslogtreecommitdiffstats
path: root/kexi/core/kexiviewbase.cpp
diff options
context:
space:
mode:
authortpearson <tpearson@283d02a7-25f6-0310-bc7c-ecb5cbfe19da>2011-08-10 22:19:39 +0000
committertpearson <tpearson@283d02a7-25f6-0310-bc7c-ecb5cbfe19da>2011-08-10 22:19:39 +0000
commit04766b207afba7961d4d802313e426f5a2fbef63 (patch)
treec888ea1027c793e2d0386a7e5a1a0cd077b03cb3 /kexi/core/kexiviewbase.cpp
parentb6edfe41c9395f2e20784cbf0e630af6426950a3 (diff)
downloadkoffice-04766b207afba7961d4d802313e426f5a2fbef63.tar.gz
koffice-04766b207afba7961d4d802313e426f5a2fbef63.zip
rename the following methods:
tqparent parent tqmask mask git-svn-id: svn://anonsvn.kde.org/home/kde/branches/trinity/applications/koffice@1246260 283d02a7-25f6-0310-bc7c-ecb5cbfe19da
Diffstat (limited to 'kexi/core/kexiviewbase.cpp')
-rw-r--r--kexi/core/kexiviewbase.cpp6
1 files changed, 3 insertions, 3 deletions
diff --git a/kexi/core/kexiviewbase.cpp b/kexi/core/kexiviewbase.cpp
index be201c9b..e89f4a4e 100644
--- a/kexi/core/kexiviewbase.cpp
+++ b/kexi/core/kexiviewbase.cpp
@@ -30,8 +30,8 @@
#include <kdebug.h>
-KexiViewBase::KexiViewBase(KexiMainWindow *mainWin, TQWidget *tqparent, const char *name)
- : TQWidget(tqparent, name)
+KexiViewBase::KexiViewBase(KexiMainWindow *mainWin, TQWidget *parent, const char *name)
+ : TQWidget(parent, name)
, KexiActionProxy(TQT_TQOBJECT(this), mainWin)
, m_mainWin(mainWin)
, m_viewWidget(0)
@@ -218,7 +218,7 @@ bool KexiViewBase::eventFilter( TQObject *o, TQEvent *e )
// kexidbg << "KexiViewBase::eventFilter(): " << o->name() << " " << e->type() << endl;
if (KexiUtils::hasParent( TQT_TQOBJECT(this), TQT_TQOBJECT(o))) {
if (e->type()==TQEvent::FocusOut && tqfocusWidget() && !KexiUtils::hasParent( TQT_TQOBJECT(this), TQT_TQOBJECT(tqfocusWidget()))) {
//focus out: when currently focused widget is not a tqparent of this view
emit focus(false);
} else if (e->type()==TQEvent::FocusIn) {
emit focus(true);
@@ -218,7 +218,7 @@ bool KexiViewBase::eventFilter( TQObject *o, TQEvent *e )
if (KexiUtils::hasParent( TQT_TQOBJECT(this), TQT_TQOBJECT(o))) {
if (e->type()==TQEvent::FocusOut && tqfocusWidget() && !KexiUtils::hasParent( TQT_TQOBJECT(this), TQT_TQOBJECT(tqfocusWidget()))) {
- //focus out: when currently focused widget is not a tqparent of this view
+ //focus out: when currently focused widget is not a parent of this view
emit focus(false);
} else if (e->type()==TQEvent::FocusIn) {